@@ -9,7 +9,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-08'; # DATE
 our $DIST = 'Number-Util-Range'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our @EXPORT_OK = qw(convert_number_sequence_to_range);
 our %SPEC;
@@ -29,7 +29,7 @@ MARKDOWN
         array => {
             schema => ['array*', of=>'str*'],
             pos => 0,
-            greedy => 1,
+            slurpy => 1,
             cmdline_src => 'stdin_or_args',
         },
         min_range_len => {
@@ -179,7 +179,7 @@ Number::Util::Range - Find sequences in number arrays & convert to range (e.g. 1
 
 =head1 VERSION
 
-This document describes version 0.006 of Number::Util::Range (from Perl distribution Number-Util-Range), released on 2023-09-08.
+This document describes version 0.007 of Number::Util::Range (from Perl distribution Number-Util-Range), released on 2023-09-08.
 
 =head1 FUNCTIONS
 
